@@ -3,7 +3,7 @@ package Archive::Tar::Constant;
 BEGIN {
     require Exporter;
 
-    $VERSION    = '2.18';
+    $VERSION    = '2.30';
     @ISA        = qw[Exporter];
 
     require Time::Local if $^O eq "MacOS";
@@ -11,6 +11,9 @@ BEGIN {
 
 @EXPORT = Archive::Tar::Constant->_list_consts( __PACKAGE__ );
 
+use strict;
+use warnings;
+
 use constant FILE           => 0;
 use constant HARDLINK       => 1;
 use constant SYMLINK        => 2;
